/**
 *  Copyright 2005 Roman Kennke
 *
 *  This file is part of Xebeche.
 *
 *  Xebeche is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  Xebeche is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with Xebeche; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

package org.kennke.xebece;

import java.io.IOException;

import java.net.URL;

/**
 *
 * @author  roman
 */
public class InfoDialog extends javax.swing.JDialog {
    
    /** Creates new form InfoDialog */
    public InfoDialog(java.awt.Frame parent, boolean modal) {
        super(parent, modal);
        initComponents();
    }
    
    /** This method is called from within the constructor to
     * initialize the form.
     * WARNING: Do NOT modify this code. The content of this method is
     * always regenerated by the Form Editor.
     */
    private void initComponents() {//GEN-BEGIN:initComponents
        mainPanel = new javax.swing.JPanel();
        scrollPane = new javax.swing.JScrollPane();
        infoTextPane = new javax.swing.JEditorPane();
        buttonPanel = new javax.swing.JPanel();
        closeButton = new javax.swing.JButton();

        setDefaultCloseOperation(javax.swing.WindowConstants.DISPOSE_ON_CLOSE);
        MessageFactory mf = MessageFactory.newInstance();
        setTitle(mf.getMessage("dialog.info.title"));
        setName("infoDialog");
        setResizable(false);
        mainPanel.setLayout(new javax.swing.BoxLayout(mainPanel, javax.swing.BoxLayout.Y_AXIS));

        mainPanel.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(12, 12, 11, 11)));
        scrollPane.setMaximumSize(new java.awt.Dimension(400, 300));
        scrollPane.setMinimumSize(new java.awt.Dimension(400, 150));
        scrollPane.setPreferredSize(new java.awt.Dimension(400, 220));
        infoTextPane.setEditable(false);
        infoTextPane.setEditorKit(new javax.swing.text.html.HTMLEditorKit());
        scrollPane.setViewportView(infoTextPane);

        mainPanel.add(scrollPane);

        buttonPanel.setLayout(new java.awt.FlowLayout(java.awt.FlowLayout.RIGHT, 0, 0));

        buttonPanel.setBorder(new javax.swing.border.EmptyBorder(new java.awt.Insets(17, 0, 0, 0)));
        closeButton.setText(mf.getMessage("dialog.info.button.close.text"));
        closeButton.addActionListener(new java.awt.event.ActionListener() {
            public void actionPerformed(java.awt.event.ActionEvent evt) {
                closeButtonActionPerformed(evt);
            }
        });

        buttonPanel.add(closeButton);

        mainPanel.add(buttonPanel);

        getContentPane().add(mainPanel, java.awt.BorderLayout.CENTER);

        pack();
    }//GEN-END:initComponents

    private void closeButtonActionPerformed(java.awt.event.ActionEvent evt) {//GEN-FIRST:event_closeButtonActionPerformed
        dispose();
    }//GEN-LAST:event_closeButtonActionPerformed
    
    /**
     * @param args the command line arguments
     */
    public static void main(String args[]) {
        java.awt.EventQueue.invokeLater(new Runnable() {
            public void run() {
                new InfoDialog(new javax.swing.JFrame(), true).setVisible(true);
            }
        });
    }

    /*
     * Sets the to-be-displayed info text. This text is expected to be HTML.
     *
     * @param text the text to be set
     */
    public void setInfoText(String text) {
        infoTextPane.setText(text);
    }

    /*
     * Sets the to-be-displayed info text. This text is expected to be an
     * URL that loads a HTML page.
     *
     * @param url the text to be set
     */
    public void setInfoUrl(URL url) {
        try {
            infoTextPane.setPage(url);
        } catch (IOException ex) {
            System.err.println("info text nicht gefunden");
        }
    }


    // Variables declaration - do not modify//GEN-BEGIN:variables
    private javax.swing.JPanel buttonPanel;
    private javax.swing.JButton closeButton;
    private javax.swing.JEditorPane infoTextPane;
    private javax.swing.JPanel mainPanel;
    private javax.swing.JScrollPane scrollPane;
    // End of variables declaration//GEN-END:variables
    
}
